[![Version](https://img.shields.io/pypi/v/tkyml?color=blue)](https://pypi.org/project/tkyml/)
[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://github.com/LoucasMaillet/tkyml/blob/master/LICENSE/)


# Project tkyml

Just a relatively simple module to separate declarative and programative part of the creation of a tkinter UI.
The declarative part is in a yaml file while we reach our needed widget and used it in the python code (logic).
It's fully python based so it may be not very fast but it will do the thing on small project.

See more about the syntax and plus in the [documentations](https://github.com/LoucasMaillet/tkyml/tree/master/docs),
also you should go check the [exemples](https://github.com/LoucasMaillet/tkyml/tree/master/exemples) to learn a bit more.

## Warning

The project isn't available on other OS than windows due to depencies of some windows only modules allowing transparency on widget.

# Installation

It is now available on pypi [here](https://pypi.org/project/tkyml/) so you can go along with :

`pip install tkyml`

# Authors

- [@LoucasMaillet](https://www.github.com/LoucasMaillet)

